<?php
/**
 * Contains functions related to GD captcha templates.
 *
 * @since 1.0.0
 * @package GeoDirectory_ReCaptcha
 */

// MUST have WordPress.
if ( !defined( 'WPINC' ) )
	exit( 'Do NOT access this file directly: ' . basename( __FILE__ ) );

/**
 * ReCaptcha settings form content.
 *
 * @since 1.0.0
 * @package GeoDirectory_ReCaptcha
 *
 * @param string $tab_name Tab name.
 */
function geodir_recaptcha_get_option_form( $tab_name ) {
	switch ( $tab_name ) {
		case 'gdcaptcha_settings': {
			geodir_admin_fields( geodir_recaptcha_settings() );
			?>
<p class="submit">
  <input name="save" class="button-primary" type="submit" value="<?php _e( 'Save changes', 'geodir-recaptcha' ); ?>" />
  <input type="hidden" name="subtab" value="gdcaptcha_settings" id="last_tab" />
</p>
</div>
		<?php
		}
		break;		
	}// end of switch
}

/**
 * captcha language, see https://developers.google.com/recaptcha/docs/language
 *
 * @since 1.0.0
 * @package GeoDirectory_ReCaptcha
 *
 * @param string $default The default language.
 * @return string Language code.
 */
function geodir_recaptcha_language( $default = 'en' ) {
	$current_lang = get_locale();
	
	$current_lang = $current_lang != '' ? $current_lang : $default;
	
	$special_lang = array( 'zh-CN', 'zh-TW', 'en-GB', 'fr-CA', 'de-AT', 'de-CH', 'pt-BR', 'pt-PT', 'es-419' );
	if ( !in_array( $current_lang, $special_lang ) ) {
		$current_lang = substr( $current_lang, 0, 2 );
	}

    /**
     * Filters the recaptcha api language.
     *
     * @since 1.0.0
     * @package GeoDirectory_ReCaptcha
     */
	$language = apply_filters( 'geodir_recaptcha_api_language', $current_lang );
	
	return $language;
}

/**
 * Displays ReCaptcha form code.
 *
 * @since 1.0.0
 * @package GeoDirectory_ReCaptcha
 *
 * @global object $bp BuddyPress object.
 *
 * @param string $form The form name.
 * @param string $extra_class Extra HTML classes.
 */
function geodir_recaptcha_display( $form, $extra_class='' ) {
	$site_key = get_option( 'geodir_recaptcha_site_key' );
	$secret_key = get_option( 'geodir_recaptcha_secret_key' );
	
	if ( strlen( $site_key ) > 10 && strlen( $secret_key ) > 10 ) {
		$captcha_title = get_option( 'geodir_recaptcha_title' );
				
		$language = geodir_recaptcha_language();
		$captcha_theme = geodir_recaptcha_theme();
        /**
         * Filters the recaptcha title.
         *
         * @since 1.0.0
         * @package GeoDirectory_ReCaptcha
         */
		$captcha_title = apply_filters( 'geodir_recaptcha_captcha_title', $captcha_title );
		
		$ajax = ( defined( 'DOING_AJAX' ) && DOING_AJAX );
		$div_id = 'gdcaptcha_' . $form;
		?>
		<div class="gd-captcha gd-captcha-<?php echo $form;?> <?php echo $extra_class;?>" style="margin:7px 0">
		<?php if ( trim( $captcha_title ) != '' ) { ?><label class="gd-captcha-title"><?php _e( $captcha_title ) ;?></label><?php } ?>
		<?php if ( $form == 'bp_registration' ) { global $bp; if ( !empty( $bp->signup->errors['gd_recaptcha_field'] ) ) { ?>
		<div class="error"><?php echo $bp->signup->errors['gd_recaptcha_field'];?></div>
		<?php } } ?>
		<div id="<?php echo $div_id;?>" class="gd-captcha-render"></div>
		<?php
		if ( $ajax ) { 
		?>
		<script type="text/javascript">
		try {
			var <?php echo $div_id;?> = function() {
			}
			jQuery(function() {
				jQuery.getScript( 'https://www.google.com/recaptcha/api.js?onload=<?php echo $div_id;?>&hl=<?php echo $language;?>&render=explicit' ).
					done(function( script, textStatus ) {
						if (typeof grecaptcha == 'undefined') {
							var to;
							clearInterval(to);
							to = setInterval(function(){
								if ( typeof grecaptcha != 'undefined' ) {
									clearInterval(to);
									if ( !jQuery('#<?php echo $div_id;?>').html() ) {										
										grecaptcha.render('<?php echo $div_id;?>', { 'sitekey' : '<?php echo $site_key;?>', 'theme' : '<?php echo $captcha_theme;?>' });
									}
								}
							}, 50);
						} else {
							if ( !jQuery('#<?php echo $div_id;?>').html() ) {
								grecaptcha.render('<?php echo $div_id;?>', { 'sitekey' : '<?php echo $site_key;?>', 'theme' : '<?php echo $captcha_theme;?>' });
							}
						}
					})
					.fail(function( jqxhr, settings, exception ) { console.log( exception ); });
			});
		} catch(err) {
			console.log(err);
		}
		</script>
		<?php } else { ?>
		<script type="text/javascript">
		try {
			var <?php echo $div_id;?> = function() {
				if ( ( typeof jQuery != 'undefined' && !jQuery('#<?php echo $div_id;?>').html() ) || '<?php echo $form;?>'=='registration' ) {
					grecaptcha.render('<?php echo $div_id;?>', { 'sitekey' : '<?php echo $site_key;?>', 'theme' : '<?php echo $captcha_theme;?>' });
				}
			}
		} catch(err) {
			console.log(err);
		}
		if ( typeof grecaptcha != 'undefined' && grecaptcha ) {
			<?php echo $div_id;?>();
		}
		</script>
		<script type="text/javascript" src="https://www.google.com/recaptcha/api.js?onload=<?php echo $div_id;?>&hl=<?php echo $language;?>&render=explicit" async defer></script>
		<?php
		}
		?>
		</div>
		<?php
	} else {
		$plugin_settings_link = admin_url( '/admin.php?page=geodirectory&tab=geodir_recaptcha&subtab=gdcaptcha_settings' );
		?>
		<div class="gd-captcha gd-captcha-<?php echo $form; ?>">
			<div class="gd-captcha-err"><?php echo sprintf( __( 'To use reCAPTCHA you must get an API key from  <a target="_blank" href="https://www.google.com/recaptcha/admin">here</a> and enter keys in the plugin settings page at <a target="_blank" href="%s">here</a>' ), $plugin_settings_link ); ?></div>
		</div>
		<?php
	}
}
?>